==> library1.4.1.tar.bz2: library/typeizd/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title = $TEXT['tip-izd-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['tip_izd_id'])>5) {puterror($result2['skin'],$TEXT['error-tip-izd6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['tip_izd_id'] = rep($_GET['tip_izd_id']);
  
  $old_tip_izd_id = $_GET['tip_izd_id'];

  $query10 = "SELECT * FROM `tbl_tip_izd` WHERE `tip_izd_id`='".$_GET['tip_izd_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl15']); require_once "../utils/bottom_adm.php"; exit();}
   $result_izd = mysqli_fetch_array($result10);
    $izd = $result_izd['tip_izd'];
    $pos = $result_izd['position'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=30 maxlength=127 type=text name=tip_izd value='<?php echo $izd; ?>'></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-lang-pos']; ?>:</td><td class="bold_it"><input size=5 maxlength=5 type=text name=position value="<?php echo $pos; ?>" ></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' />
<input type=hidden name=izd_id value='<?php echo $old_tip_izd_id; ?>' />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/typeizd/editform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////
  require_once "../utils/chlang.php";

  $title = $TEXT['tip-izd-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  $button = $TEXT['btn_save'];
  $action = "edit.php";

  if(strlen($_GET['tip_izd_id'])>5) {puterror($result2['skin'],$TEXT['error-tip-izd6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['tip_izd_id'] = rep($_GET['tip_izd_id']);
  
  $old_tip_izd_id = $_GET['tip_izd_id'];

  $query10 = "SELECT * FROM `tbl_tip_izd` WHERE `tip_izd_id`='".$_GET['tip_izd_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl15']); require_once "../utils/bottom_adm.php"; exit();}
   $result_izd = mysqli_fetch_array($result10);
    $izd = rep_back($result_izd['tip_izd']);
    $pos = $result_izd['position'];
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="inform"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size="30" maxlength="127" type="text" name="tip_izd" value="<?php echo $izd; ?>" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-lang-pos']; ?>:</td><td class="bold_it"><input size="5" maxlength="5" type="text" name="position" value="<?php echo $pos; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" />
<input type="hidden" name="izd_id" value="<?php echo $old_tip_izd_id; ?>" />
</td></tr>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
